@@ -28,3 +28,8 @@ def add_watermark(file, mark, out="output", color="#8B8B1B", size=30, opacity=0.
 @except_dec()
 def img2Cartoon(path, client_api='OVALewIvPyLmiNITnceIhrYf', client_secret='rpBQH8WuXP4ldRQo5tbDkv3t0VgzwvCN'):
     mainImage.img2Cartoon(path, client_api, client_secret)
+
+
+@except_dec()
+def down4img(url, output_name='down4img', type='jpg'):
+    mainImage.down4img(url, output_name, type)
