@@ -37,5 +37,5 @@ def lottery8ticket():
     mainTools.lottery8ticket()
 
 
-def create_article(theme):
-    mainTools.create_article(theme)
+def create_article(theme, line_num=200):
+    mainTools.create_article(theme, line_num)
